@@ -707,8 +707,8 @@ void ImportMailJob::restoreConfig()
 
             bool canceled = false;
             MailCommon::FilterImporterExporter exportFilters;
-            QVector<MailCommon::MailFilter *> lstFilter = exportFilters.importFilters(canceled, MailCommon::FilterImporterExporter::KMailFilter, filterFileName);
-            if (canceled) {
+            const QVector<MailCommon::MailFilter *> lstFilter = exportFilters.importFilters(canceled, MailCommon::FilterImporterExporter::KMailFilter, filterFileName);
+            if (!canceled) {
                 MailCommon::FilterManager::instance()->appendFilters(lstFilter);
             }
         }
@@ -1023,9 +1023,9 @@ void ImportMailJob::restoreIdentity()
                         }
                     }
                 }
-                QString name = group.readEntry(QStringLiteral("Name"));
+                QString name = uniqueIdentityName(group.readEntry(QStringLiteral("Name")));
 
-                KIdentityManagement::Identity *identity = &mIdentityManager->newFromScratch(uniqueIdentityName(name));
+                KIdentityManagement::Identity *identity = &mIdentityManager->newFromScratch(name);
                 group.writeEntry(QStringLiteral("Name"), name);
                 group.sync();
 
@@ -1195,7 +1195,13 @@ void ImportMailJob::importKmailConfig(const KArchiveFile *kmailsnippet, const QS
         if (!path.isEmpty()) {
             KConfigGroup oldGroup = kmailConfig->group(str);
             ImportExportMailUtil::cleanupFolderSettings(oldGroup);
-            if (!oldGroup.groupList().isEmpty()) {
+            if (!oldGroup.keyList().isEmpty()) {
+                if (oldGroup.hasKey(QStringLiteral("Identity"))) {
+                    const int identity = oldGroup.readEntry(QStringLiteral("Identity"), -1);
+                    if (identity != -1) {
+                        oldGroup.writeEntry(QStringLiteral("Identity"), mHashIdentity.value(identity));
+                    }
+                }
                 const Akonadi::Collection::Id id = convertPathToId(path);
                 if (id != -1) {
                     KConfigGroup newGroup(kmailConfig, folderGroupPattern + QString::number(id));
@@ -1288,7 +1294,7 @@ void ImportMailJob::importKmailConfig(const KArchiveFile *kmailsnippet, const QS
             KConfigGroup newGroup(kmailConfig, QStringLiteral("Automatic Add Contacts %1").arg(i.value()));
             identityGroup.copyTo(&newGroup);
             const QString automaticAddContactStr(QStringLiteral("Collection"));
-            convertRealPathToCollectionList(newGroup, automaticAddContactStr);
+            convertRealPathToCollectionList(newGroup, automaticAddContactStr, false);
             identityGroup.deleteGroup();
         }
         ++i;
