@@ -74,12 +74,17 @@ void ImportNotesJob::start()
 {
     Q_EMIT title(i18n("Starting to import KNotes settings..."));
     mArchiveDirectory = archive()->directory();
-    // FIXME search archive ? searchAllFiles(mArchiveDirectory, QString());
+    searchAllFiles(mArchiveDirectory, QString(), QStringLiteral("note"));
     createProgressDialog(i18n("Import KNotes settings"));
     initializeListStep();
     QTimer::singleShot(0, this, &ImportNotesJob::slotNextStep);
 }
 
+bool ImportNotesJob::isAConfigFile(const QString &name) const
+{
+    return name.endsWith(QLatin1String("rc")) && (name.contains(QLatin1String("akonadi_akonotes_resource_")));
+}
+
 void ImportNotesJob::restoreConfig()
 {
     increaseProgressDialog();
